@@ -5,5 +5,5 @@
 from .cv_image import CVImage
 from .cv_queue import CVQueue
 from .cv_file import CVFile
-from .cv_video import CVVideo
+from .cv_video import CVVideo, CVVideoLoader
 
